/************************************************
  Applied Biometric Systems GmbH (C) 2002-2009
     		     ERELC.H 
************************************************/

#ifndef __EREL11XC_H
#define __EREL11XC_H

#define WIN32_LEAN_AND_MEAN

#include <stdlib.h>
#include <windows.h>
#include <winsock2.h>


#ifdef EREL11XC_EXPORTS
	#define ERELC __declspec( dllexport )
#else
	#ifdef EREL11XC_IMPORTS
		#define ERELC  __declspec( dllimport )
	#else
		#define ERELC
	#endif
#endif

typedef	unsigned char byte;


#define	TYPEDEVICE_EREL11X		1112
#define	TYPEDEVICE_EREL112		1112

#define ISNOTPRESENT				0

                                       
#define	rcOK						0
#define	rcFINGER_NOT_PRESENT		1
	
#define ERROR_DEVICE_NOTPRESENT		-3
#define	ERROR_TIMEOUT_RECV			-20
#define	ERROR_MEMORY_ALLOC			-21


#define	S_RELAY_1	0x01
#define	S_RELAY_2	0x02
#define	S_RELAY_3	0x04
#define	S_RELAY_4	0x08
#define	S_RELAY_5	0x10
#define	S_RELAY_6	0x20
#define	S_RELAY_7	0x40
#define	S_RELAY_8	0x80



#if defined (__cplusplus)
extern "C" {
#endif

int	ERELC	erelOpenDevice(int typescanner, unsigned char * addr, int port);
int	ERELC	erelCloseDevice(int handle);
void ERELC  erelSetOpenTimeout(int timeout);

int	ERELC	erelGetVersion(int handle, unsigned char * version);
int	ERELC	erelSetParam(int handle, unsigned char * param);
int	ERELC	erelSetParamX(int handle, unsigned char * param);
int	ERELC	erelGetParam(int handle, unsigned char * param);
int	ERELC	erelGetParamX(int handle, unsigned char * param);
int	ERELC	erelReboot(int handle);

byte ERELC * efisGetSDKVersion(void);

int	ERELC erelRelaySwitchByte(int handle, unsigned char sw);

int	ERELC	erelRelayOn(int handle, unsigned char nRelay);
int	ERELC	erelRelayOnE16(int handle, unsigned short nRelay);
int	ERELC	erelRelayOff(int handle, unsigned char nRelay);
int	ERELC	erelRelayOffE16(int handle, unsigned short nRelay);

int	ERELC	erelRelayOnTimer(int handle, unsigned char nRelay, unsigned char nTime);
int	ERELC	erelRelayOnTimerE16(int handle, unsigned short nRelay, unsigned char nTime);

int	ERELC	erelAllRelayOff(int handle);
int ERELC	erelGetStatusRelay(int handle, unsigned char * out);
int ERELC	erelGetStatusRelayE16(int handle, unsigned char * out);
int ERELC	erelGetStatusInput(int handle, unsigned char * out);
int ERELC	erelGetAnswer(int handle, unsigned char * out);

int	ERELC	erelSendInputStatusOn(int handle);
int	ERELC	erelSendInputStatusOff(int handle);


int ERELC	erelGetTemperature(int handle, double * temp);

int	ERELC	erelAccessToCalendar(int handle, unsigned char access);


int	ERELC	erelWriteI2C(int handle, unsigned char adr, unsigned char reg, unsigned char val);
int	ERELC	efisReadI2CB(int handle, unsigned char adr, unsigned char reg, unsigned char * val);
int	ERELC	erelReadI2CW(int handle, unsigned char adr, unsigned char reg, unsigned short * val);

int	ERELC	erelSetTime(int handle, unsigned char day, unsigned char mon, unsigned char year, unsigned char hour, unsigned char min, unsigned char sec);
int	ERELC	erelGetTime(int handle, unsigned char * day, unsigned char * mon, unsigned char * year, unsigned char * hour, unsigned char * min, unsigned char * sec);
int	ERELC	erelGetDOW(int handle, unsigned char * dow);	//	Day of Week, 1 - Sunday, 2 - Monday, .... 7 - Saturday

int	ERELC	erelSetTimeM3(int handle, unsigned char day, unsigned char mon, unsigned short year, unsigned char hour, unsigned char min, unsigned char sec);
int	ERELC	erelGetTimeM3(int handle, unsigned char * day, unsigned char * mon, unsigned short * year, unsigned char * hour, unsigned char * min, unsigned char * sec, unsigned char * dow);

int	ERELC erelGetCalibrationM3(int handle, unsigned char * val);
int	ERELC erelSetCalibrationM3(int handle, unsigned char val);

//	access to dataflash
int	ERELC	erel_DF_SetPowerOf2(int handle);
int	ERELC	erel_DF_ReadStatus(int handle);
int	ERELC	erel_DF_ReadCounter(int handle, unsigned long * counter);
int	ERELC	erel_DF_WriteCounter(int handle, unsigned long counter);
int	ERELC	erel_DF_SaveBuftoMain(int handle);
int	ERELC	erel_DF_ReadDataFlash(int handle, unsigned long addr, short len, unsigned char * b);
int	ERELC	erel_DF_WriteDataFlash(int handle, unsigned long addr, short len, unsigned char * b);


int	ERELC erel_DF_ReadStatusM3(int handle, unsigned char * val);
int	ERELC erel_DF_ReadStatusReadyM3(int handle, unsigned char * val);
int	ERELC erel_DF_SetPowerOf2M3(int handle, unsigned char * val);
int	ERELC erel_DF_WriteDataFlashM3(int handle, unsigned long addr, short len, unsigned char * b);
int	ERELC erel_DF_ReadDataFlashM3(int handle, unsigned long addr, short len, unsigned char * b);

int	ERELC erelUpdateFirmwareM3(int handle, unsigned char * b, unsigned long length);

int	ERELC	erelSetInvertInpMask(int handle, unsigned char maskl, unsigned char maskh);
int	ERELC	erelGetInvertInpMask(int handle, unsigned char * maskl, unsigned char * maskh);
int	ERELC	erelSetInvertOutMask(int handle, unsigned char maskl, unsigned char maskh);
int	ERELC	erelGetInvertOutMask(int handle, unsigned char * maskl, unsigned char * maskh);


int	CommonInit(void);
int	CommonReset(void);



#if defined (__cplusplus)          /* !defined (__cplusplus) */
}
#endif

#endif

